@@ -8,12 +8,12 @@ class EthiopLit(BaseLit):
 
     def __init__(self):
         super().__init__()
-        self.ascii_rows = [
+        self.ascii_rows = (
             "h",
             "l",
             ".h",
             "m",
-            "’s",
+            "'s",
             "r",
             "s",
             "^s",
@@ -29,7 +29,7 @@ class EthiopLit(BaseLit):
             "_h",
             "n",
             "~n",
-            "’",
+            "'",
             "k",
             "k",
             "_k",
@@ -52,13 +52,13 @@ class EthiopLit(BaseLit):
             ".c",
             "f",
             "p",
-            "’q",
-            "’k",
-            "’h",
-            "’g",
-        ]
-        self.ascii_cols = ["a", "u", "i", "A", "E", "e", "o"]
-        self.ascii_cols_labial = ["ua", "=", "ui", "uA", "uuE", "ue", "="]
+            "'q",
+            "'k",
+            "'h",
+            "'g",
+        )
+        self.ascii_cols = ("a", "u", "i", "A", "E", "e", "o")
+        self.ascii_cols_labial = ("ua", "=", "ui", "uA", "uuE", "ue", "=")
         self.geez_rows_labial = {9, 11, 17, 22, 24, 34, 36}
         self.geez_puncs = {
             "።": "::",
